@@ -7,18 +7,19 @@ from uadm.uadmcore import *
 if __name__ == '__main__':
 
     mod_conf({
-        'UADM_AUTO_MOUNT_USE_CENTRIFY' : True,
+        'UADM_USE_CENTRIFY' : True,
     }, override=False)
 
     mod_conf({
+        'UADM_DISABLE_MAIL' : True,
     })
 
-    site_name = "%(template_site_name)s"
-    site_group = "%(template_group_name)s"
+    site_name = "${template_site_name}"
+    site_group = "${template_group_name}"
     pam_user = os.getenv('PAM_USER')
-    l().info("!!!")
+
     cmd_list = ['bash -c \'id %s | grep "%s"  2> /dev/null\'' % (pam_user, site_group)]
-    if CONF_MAP['UADM_PAM_SCRIPT_USE_CENTRIFY']:
+    if CONF_MAP['UADM_USE_CENTRIFY']:
         cmd_list.append('bash -c \'adquery user %s -a 2> /dev/null | grep "%s"\'' % (pam_user, site_group))
 
     is_member = False
@@ -39,7 +40,6 @@ if __name__ == '__main__':
         if is_mounted:
             cmd_list.insert(0, 'umount /home/%(user)s/%(site)s' % {'user':pam_user, 'site':site_name})
 
-        l().info(cmd_list)
         exec_cmd_list(cmd_list)
     else:
         l().info("NO MEMBERS")
